@@ -4,7 +4,6 @@ from PyQt5.QtCore import QCoreApplication as QC
 from slugify import slugify
 from datetime import datetime
 import re
-import json
 import sys
 import os
 import pwd
@@ -24,11 +23,11 @@ DIALOG_UI_PATH = "%s/../res/ruleseditor.ui" % os.path.dirname(sys.modules[__name
 class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
 
     LOG_TAG = "[rules editor]"
-    classA_net = "10\.\d{1,3}\.\d{1,3}\.\d{1,3}"
-    classB_net = "172\.1[6-9]\.\d+\.\d+|172\.2[0-9]\.\d+\.\d+|172\.3[0-1]+\.\d{1,3}\.\d{1,3}"
-    classC_net = "192\.168\.\d{1,3}\.\d{1,3}"
-    others_net = "127\.\d{1,3}\.\d{1,3}\.\d{1,3}|169\.254\.\d{1,3}\.\d{1,3}"
-    multinets = "2[32][23459]\.\d{1,3}\.\d{1,3}\.\d{1,3}"
+    classA_net = r'10\.\d{1,3}\.\d{1,3}\.\d{1,3}'
+    classB_net = r'172\.1[6-9]\.\d+\.\d+|172\.2[0-9]\.\d+\.\d+|172\.3[0-1]+\.\d{1,3}\.\d{1,3}'
+    classC_net = r'192\.168\.\d{1,3}\.\d{1,3}'
+    others_net = r'127\.\d{1,3}\.\d{1,3}\.\d{1,3}|169\.254\.\d{1,3}\.\d{1,3}'
+    multinets = r'2[32][23459]\.\d{1,3}\.\d{1,3}\.\d{1,3}'
     MULTICAST_RANGE = "^(" + multinets + ")$"
     LAN_RANGES = "^(" + others_net + "|" + classC_net + "|" + classB_net + "|" + classA_net + "|::1|f[cde].*::.*)$"
     LAN_LABEL = "LAN"
@@ -434,13 +433,7 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
         if self.rule.operator.type != Config.RULE_TYPE_LIST:
             self._load_rule_operator(self.rule.operator)
         else:
-            rule_options = json.loads(self.rule.operator.data)
-            for r in rule_options:
-                _sensitive = False
-                if 'sensitive' in r:
-                    _sensitive = r['sensitive']
-
-                op = ui_pb2.Operator(type=r['type'], operand=r['operand'], data=r['data'], sensitive=_sensitive)
+            for op in self.rule.operator.list:
                 self._load_rule_operator(op)
 
         return True
@@ -569,17 +562,7 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
     def _insert_rule_to_db(self, node_addr):
         # the order of the fields doesn't matter here, as long as we use the
         # name of the field.
-        self._db.insert("rules",
-            "(time, node, name, description, enabled, precedence, nolog, action, "\
-                        "duration, operator_type, operator_sensitive, operator_operand, operator_data, created)",
-                        (datetime.now().strftime("%Y-%m-%d %H:%M:%S"),
-                         node_addr, self.rule.name, self.rule.description,
-                         str(self.rule.enabled), str(self.rule.precedence), str(self.rule.nolog),
-                         self.rule.action, self.rule.duration, self.rule.operator.type,
-                         str(self.rule.operator.sensitive), self.rule.operator.operand, self.rule.operator.data,
-                         str(datetime.fromtimestamp(self.rule.created).strftime("%Y-%m-%d %H:%M:%S"))),
-                         action_on_conflict="REPLACE"
-                        )
+        self._rules.add_rules(node_addr, [self.rule])
 
     def _add_rule(self):
         try:
@@ -922,7 +905,7 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                         'data': self.dstListsLine.text(),
                         'sensitive': self.sensitiveCheck.isChecked()
                         })
-            self.rule.operator.data = json.dumps(rule_data)
+            self.rule.operator.data = ""
 
         if self.dstListRegexpCheck.isChecked():
             if self.dstRegexpListsLine.text() == "":
@@ -939,7 +922,7 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                         'data': self.dstRegexpListsLine.text(),
                         'sensitive': self.sensitiveCheck.isChecked()
                         })
-            self.rule.operator.data = json.dumps(rule_data)
+            self.rule.operator.data = ""
 
         if self.dstListNetsCheck.isChecked():
             if self.dstListNetsLine.text() == "":
@@ -956,7 +939,7 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                         'data': self.dstListNetsLine.text(),
                         'sensitive': self.sensitiveCheck.isChecked()
                         })
-            self.rule.operator.data = json.dumps(rule_data)
+            self.rule.operator.data = ""
 
 
         if self.dstListIPsCheck.isChecked():
@@ -974,12 +957,22 @@ class RulesEditorDialog(QtWidgets.QDialog, uic.loadUiType(DIALOG_UI_PATH)[0]):
                         'data': self.dstListIPsLine.text(),
                         'sensitive': self.sensitiveCheck.isChecked()
                         })
-            self.rule.operator.data = json.dumps(rule_data)
+            self.rule.operator.data = ""
 
         if len(rule_data) >= 2:
             self.rule.operator.type = Config.RULE_TYPE_LIST
             self.rule.operator.operand = Config.RULE_TYPE_LIST
-            self.rule.operator.data = json.dumps(rule_data)
+            self.rule.operator.data = ""
+            for rd in rule_data:
+                self.rule.operator.list.extend([
+                    ui_pb2.Operator(
+                        type=rd['type'],
+                        operand=rd['operand'],
+                        data=rd['data'],
+                        sensitive=rd['sensitive']
+                    )
+                ])
+                print(self.rule.operator.list)
 
         elif len(rule_data) == 1:
             self.rule.operator.operand = rule_data[0]['operand']
